@@ -15,7 +15,7 @@ class EmailNotification(RedisModule):
     def __init__(
         self,
         model_identifier: str,
-        model_directory: str,
+        configuration_directory: str,
         sender: str,
         recipients: list,
         subject: str,
@@ -29,7 +29,7 @@ class EmailNotification(RedisModule):
         super().__init__(
             pipeline_module_name=PIPELINE_MODULE_NAME,
             model_identifier=model_identifier,
-            model_directory=model_directory,
+            configuration_directory=configuration_directory,
             redis_server=redis_server,
         )
 
@@ -58,7 +58,12 @@ class EmailNotification(RedisModule):
             return None
 
         template_text = self._load_template(
-            instance, os.path.join(self.model_directory, self.template_text_filename)
+            instance,
+            os.path.join(
+                self.configuration_directory,
+                self.model_identifier,
+                self.template_text_filename,
+            ),
         )
 
         if not template_text:
@@ -66,7 +71,12 @@ class EmailNotification(RedisModule):
             return None
 
         template_html = self._load_template(
-            instance, os.path.join(self.model_directory, self.template_html_filename)
+            instance,
+            os.path.join(
+                self.configuration_directory,
+                self.model_identifier,
+                self.template_html_filename,
+            ),
         )
 
         if not template_html:
@@ -112,15 +122,17 @@ class EmailNotification(RedisModule):
             variables = variables_pattern.findall(template)
             for variable in variables:
                 template = template.replace(
-                    f"[[{variable}]]", str(instance.get_attribute(variable))
+                    f"[[{variable}]]", str(instance.get_attribute(variable, default=""))
                 )
 
             return template
 
         except FileNotFoundError:
+            print("ERROR 1")
             logging.info(f"Template file {template_file} not found")
             return None
         except Exception as e:
+            print(f"ERROR 2 {e}")
             logging.exception(e)
             return None
 
