@@ -52,8 +52,8 @@ class Pipeline(object):
 
     def __init__(
         self,
-        model_identifier: str,
-        model_directory: str = None,
+        pipeline_configuration: any = None,
+        configuration_directory: str = None,
         store_configuration: dict = None,
         redis_server: str = None,
         aws_access_key: str = None,
@@ -63,16 +63,22 @@ class Pipeline(object):
     ):
         self.kwargs = kwargs
 
-        self.model_identifier = model_identifier
-        self.model_directory = model_directory
+        self.configuration_directory = configuration_directory or os.path.abspath(
+            os.getcwd()
+        )
 
         self.redis_server = redis_server
         self.aws_access_key = aws_access_key
         self.aws_secret_key = aws_secret_key
         self.aws_region_name = aws_region_name
 
+        # We are going to read the model identifier and the list of
+        # modules from the pipeline.yml file.
+        self.model_identifier = None
+        self.modules = None
+
+        self._load_pipeline_configuration(pipeline_configuration)
         self.pipeline_id = self._initialize_metadata_store(store_configuration)
-        self.modules = self._load_modules()
 
     def run(self, data: dict) -> Instance:
         instance = Instance.create(data)
@@ -119,32 +125,52 @@ class Pipeline(object):
 
         return instance
 
-    def _load_modules(self):
-        if self.model_directory is None:
+    def _load_pipeline_configuration(self, pipeline_configuration):
+        if pipeline_configuration is None:
             logging.info(
-                "Configured a default pipeline since no model directory was specified."
+                "Configured a default pipeline since no specific configuration "
+                "was specified."
             )
-            return []
+            self.model_identifier = "default"
+            self.modules = []
+            return
 
-        pipeline_config_file = os.path.join(self.model_directory, PIPELINE_FILENAME)
-        logging.info(f"Loading pipeline configuration from {pipeline_config_file}")
+        if hasattr(pipeline_configuration, "read"):
+            try:
+                pipeline_configuration = yaml.safe_load(pipeline_configuration.read())
+            except Exception as e:
+                logging.exception(e)
+                raise RuntimeError("Unable to load pipeline configuration")
+        else:
+            logging.info(
+                f"Loading pipeline configuration from {pipeline_configuration}..."
+            )
 
-        try:
-            with open(pipeline_config_file) as file:
-                pipeline_configuration = yaml.load(file.read(), Loader=yaml.FullLoader)
-        except Exception as e:
-            logging.exception(e)
+            try:
+                with open(pipeline_configuration) as file:
+                    pipeline_configuration = yaml.load(
+                        file.read(), Loader=yaml.FullLoader
+                    )
+            except Exception as e:
+                logging.exception(e)
+                raise RuntimeError(
+                    f"Unable to load pipeline configuration from file {pipeline_configuration}"
+                )
+
+        self.model_identifier = pipeline_configuration.get("name", None)
+        if self.model_identifier is None:
             raise ValueError(
-                f"Unable to load pipeline configuration {pipeline_config_file}"
+                "The name of the pipeline should be specified as part of "
+                "the configuration."
             )
 
-        modules = []
+        self.modules = []
         arguments = {
             "model_identifier": self.model_identifier,
-            "model_directory": self.model_directory,
+            "configuration_directory": self.configuration_directory,
         }
 
-        pipeline = pipeline_configuration["pipeline"]
+        pipeline = pipeline_configuration.get("pipeline", [])
 
         # If the pipeline defines a set of AWS credentials, we want to overwrite the
         # credentials that were passed in.
@@ -184,9 +210,8 @@ class Pipeline(object):
                 arguments["aws_region_name"] = self.aws_region_name
 
                 arguments.update(self.kwargs)
-                modules.append(module(**arguments))
+                self.modules.append(module(**arguments))
 
-            return modules
         except ModuleNotFoundError as e:
             raise RuntimeError(f"Unable to load module {module_path}.{module_name}")
 
@@ -200,7 +225,8 @@ class Pipeline(object):
             connection_config.fake_database.SetInParent()
         elif "file" in store_configuration:
             logging.info("Metadata store is configured to work with a SQLite database.")
-            connection_config.file_database.path = store_configuration["file"]
+            connection_config.sqlite.filename_uri = store_configuration["file"]
+            connection_config.sqlite.connection_mode = 3
         elif "host" in store_configuration:
             logging.info("Metadata store is configured to work with a MySQL database.")
             connection_config.mysql_database.host = store_configuration["host"]
@@ -229,6 +255,7 @@ class Pipeline(object):
             except NotFoundError:
                 context_type = ContextType()
                 context_type.name = Pipeline.CONTEXT_TYPE_PIPELINE
+                context_type.properties[Pipeline.CONTEXT_TYPE_PIPELINE] = 1
                 context_type_id = self.store.put_context_type(context_type)
                 logging.info(f"Created {_log_message} {context_type_id}")
 
@@ -255,6 +282,9 @@ class Pipeline(object):
             pipeline_execution_context_type.name = (
                 Pipeline.CONTEXT_TYPE_PIPELINE_EXECUTION
             )
+            pipeline_execution_context_type.properties[
+                Pipeline.CONTEXT_TYPE_PIPELINE_EXECUTION
+            ] = 1
             pipeline_execution_context_type.id = self.store.put_context_type(
                 pipeline_execution_context_type
             )
